@@ -40,6 +40,9 @@ MAX_SEED_DESCRIPTION = 'The random seed to use for reproducibility.'
 MASS_ALIGNMENT_DESCRIPTION = 'Alignment of masses within each SQT file, with recalculation of ppm based on a N-dimensional function fit to the mass-ppm drift versus retention time relationship (where N is specified by --mass_alignment_dim)'
 MASS_ALIGNMENT_DIM_DESCRIPTION = 'The number of dimensions to use in the alignment function, with 1 being linear and 2 being quadratic, etc.'
 MASS_ALIGNMENT_PERCENTILE_DESCRIPTION = 'The xcorr percentile for which to fit the mass alignment function, represented as an integer.'
+RT_ALIGNMENT_PERCENTILE_DESCRIPTION = 'The xcorr percentile for which to fit the rt alignment function, represented as an integer.'
+RT_SCORE_DESCRIPTION = 'Predict RT values for peptides and generate a RT score'
+MODIFICATION_MAP_DESCRIPTION = 'Maps the IP2 Modification to its Unitprot ID'
 
 MAX_MLINE_DESCRIPTION = 'The maximum number of m lines to be used as input for mokapot per spectra.'
 XCORR_FILTER_DESCRIPTION = 'The xcorr value to be used as a filter for PSMs before they are included in the semi-supervised training loop, only PSMs with xcorr values greater than this will be included.'
