@@ -1,4 +1,5 @@
 import argparse
+import ast
 import logging
 from io import StringIO
 from pathlib import Path
@@ -16,7 +17,7 @@ from xgboost import XGBClassifier
 from . import mokapot
 from .mokapot.parsers.fasta import _parse_protein, _parse_fasta_files, read_fasta
 from .parsing import convert_sqt_to_df, convert_to_moka, get_filter_results_moka, align_mass, parse_dta_args
-from .util import xml_to_dict
+from .util import xml_to_dict, pred_rt, calculate_memory_usage
 from .config import *
 
 
@@ -66,6 +67,10 @@ def parse_args() -> argparse.Namespace:
     _parser.add_argument('--verbosity', required=False, default=2, type=int, choices=[0,1,2,3], help=VERBOSITY_DESCRIPTION)
     _parser.add_argument('--filter_level', required=False, default=0, type=int, choices=[0,1,2], help=FILTER_LEVEL_DESCRIPTION)
 
+    _parser.add_argument('--rt_alignment_percentile', required=False, default=95, type=int,help=RT_ALIGNMENT_PERCENTILE_DESCRIPTION)
+    _parser.add_argument('--rt_score', required=False, default=False, action=argparse.BooleanOptionalAction, help=RT_ALIGNMENT_PERCENTILE_DESCRIPTION)
+    _parser.add_argument('--mod_map', required=False, default='{}', type=str, help=MODIFICATION_MAP_DESCRIPTION)
+
     return _parser.parse_args()
 
 
@@ -144,7 +149,10 @@ def run():
                                                             args.mass_alignment, args.max_mline, args.seed, dta_params,
                                                             args.xcorr_filter,
                                                             args.mass_alignment_dim, args.mass_alignment_percentile,
-                                                            args.filter_level)
+                                                            args.filter_level,
+                                                            args.rt_alignment_percentile, args.rt_score,
+                                                            ast.literal_eval(args.mod_map)
+    )
 
     with open(Path(args.out), 'w') as file:
         for i, line in enumerate(dta_filter_content):
@@ -251,7 +259,11 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
                xcorr_filter: float,
                mass_alignment_dim: int,
                mass_alignment_percentile: float,
-               filter_level: int) -> (List[matplotlib.figure.Figure], pd.DataFrame, IO[str]):
+               filter_level: int,
+               rt_alignment_percentile: int,
+               rt_score: bool,
+               mod_map: dict) -> (List[matplotlib.figure.Figure], pd.DataFrame, IO[str]):
+
     """
     What a mess of code...
 
@@ -337,9 +349,23 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
                 logging.error(f'Error aligning masses for sqt {i}: {err}')
             alignment_figs.append(fig)
 
+    if rt_score is True:
+        print(f'Scoring RT')
+        _ = [pred_rt(sqt_df, mod_map, rt_alignment_percentile) for sqt_df in sqt_dfs]
+
     sqt_df = pd.concat(sqt_dfs, ignore_index=True)
+    sqt_df['locuses'] = sqt_df['locuses'].astype("category")
+    sqt_df['file'] = sqt_df['file'].astype("category")
+    sqt_df['validation_status'] = sqt_df['validation_status'].astype("category")
+
+    print(sqt_df.dtypes, end="\n\n")
+    print(calculate_memory_usage(sqt_df))
+
     pin_df = convert_to_moka(sqt_df)
 
+    print(pin_df.dtypes, end="\n\n")
+    print(calculate_memory_usage(pin_df))
+
     fasta_elems = [_parse_protein(entry) for entry in _parse_fasta_files(fastas[0])]
     fasta_dict = {e[0]: {'sequence': e[1], 'description': e[2]} for e in fasta_elems}
 
@@ -347,6 +373,9 @@ def mokafilter(sqts: Tuple[Iterator[IO[str]], List[str]],
         pin_df['tims_score'] = sqt_df['tims_score']
         pin_df['tims_score'] = pin_df['tims_score'].fillna(value=0)
 
+    if rt_score is True:
+        pin_df['rt_diff'] = sqt_df['rt_diff']
+
     psms = mokapot.read_pin(pin_files=pin_df)
 
     # Slightly modified version of read_fasta which doesn't require opening files
