@@ -1,6 +1,18 @@
 import re
 from xml.etree import ElementTree
 import numpy as np
+import pandas as pd
+from deeplc import DeepLC
+from matplotlib import pyplot as plt
+from peptacular.peptide import parse_modified_peptide, strip_modifications, convert_to_ms2_pip_style, \
+    convert_ip2_mod_to_uniprot_mod
+from sklearn.preprocessing import MinMaxScaler
+
+def calculate_memory_usage(df_input: pd.DataFrame) -> pd.Series:
+    """Returns the real memory usage of a DataFrame including object types."""
+
+    memory_usage = df_input.memory_usage(deep=True)
+    return memory_usage
 
 def get_unmodified_peptide(peptide_sequence: str) -> str:
     """
@@ -104,16 +116,60 @@ def map_peptide_to_specid(psm_results):
         peptide_to_specid.setdefault(peptide, set()).add(specid)
     return peptide_to_specid
 
+def plot_rt_alignment(rts, shifts, pred_rt):
+    fig, ax = plt.subplots()
+    ax.scatter(rts, rts - pred_rt,  s=0.1, label='Raw')
+    ax.scatter(rts, rts - pred_rt - shifts, s=0.1, label='Aligned')
+    plt.title('RT Alignment')
+    plt.xlabel('Normalized Retention Time')
+    plt.ylabel('rt diff')
+    ax.legend()
+    return fig
 
-def strip_modifications(peptide_sequence: str) -> str:
-    """
-    Removes any non-amino-acid characters from the given peptide sequence.
+def align_rt(df, rtscore_percentile, rt_alignment_dim):
+    scaler = MinMaxScaler()
+    rts = scaler.fit_transform(df['low_scan'].values.reshape(-1, 1)).reshape(-1)
+    x_corr_perc = np.percentile(df['xcorr'], rtscore_percentile)
+    align_index = df['xcorr'] >= x_corr_perc
+    align_rts = rts[align_index]
+    align_rt_diff = (rts - df['rt_pred'])[align_index]
+    alignment_func = np.poly1d(np.polyfit(align_rts, align_rt_diff, rt_alignment_dim))
 
-    Args:
-        peptide_sequence: The peptide sequence to be stripped of modifications.
+    shifts = alignment_func(rts)
+    fig = plot_rt_alignment(rts[align_index], shifts[align_index], df['rt_pred'][align_index])
+    df['rt_pred'] = rts - shifts
+    df['rt_diff'] = rts - df['rt_pred']
+    return fig
 
-    Returns:
-        The peptide sequence with all non-amino-acid characters removed.
-    """
-    return ''.join([c for c in peptide_sequence if c in 'ACDEFGHIKLMNPQRSTVWY'])
 
+def align_mobility(df):
+    scaler = MinMaxScaler()
+    rts = scaler.fit_transform(df['low_scan'].values.reshape(-1, 1)).reshape(-1)
+    x_corr_perc = np.percentile(df['xcorr'], 95)
+    align_index = df['xcorr'] >= x_corr_perc
+    align_rts = rts[align_index]
+    align_mobility_diff = (df['experimental_ook0'] - df['predicted_ook0'])[align_index]
+    alignment_func = np.poly1d(np.polyfit(align_rts, align_mobility_diff, 1))
+    shifts = alignment_func(rts)
+    df['experimental_ook0'] = df['experimental_ook0'] - shifts
+
+
+def pred_rt(df, modification_map, rtscore_percentile):
+
+    df['rt'] = MinMaxScaler().fit_transform(df['low_scan'].values.reshape(-1, 1)).reshape(-1)
+
+    pep_df = pd.DataFrame()
+    pep_df['seq'] = [strip_modifications(seq[2:-2]) for seq in df['sequence'].values]
+    pep_df['modifications'] = [convert_to_ms2_pip_style(convert_ip2_mod_to_uniprot_mod(seq[2:-2], modification_map)) for seq in df['sequence'].values]
+
+    cal_df = pd.DataFrame()
+    perc_df = df[df['xcorr'] >= np.percentile(df['xcorr'], rtscore_percentile)]
+    cal_df['seq'] = [strip_modifications(seq[2:-2]) for seq in perc_df['sequence'].values]
+    cal_df['modifications'] = [convert_to_ms2_pip_style(convert_ip2_mod_to_uniprot_mod(seq[2:-2], modification_map)) for seq in perc_df['sequence'].values]
+    cal_df['tr'] = MinMaxScaler().fit_transform(perc_df['low_scan'].values.reshape(-1, 1)).reshape(-1)
+
+    dlc = DeepLC()
+    dlc.calibrate_preds(seq_df=cal_df)
+    preds = dlc.make_preds(seq_df=pep_df)
+    df['rt_pred'] = preds
+    df['rt_diff'] = df['rt_pred'] - df['rt']
